# mypy-boto3-autoscaling

[![PyPI - mypy-boto3-autoscaling](https://img.shields.io/pypi/v/mypy-boto3-autoscaling.svg?color=blue)](https://pypi.org/project/mypy-boto3-autoscaling)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-autoscaling.svg?color=blue)](https://pypi.org/project/mypy-boto3-autoscaling)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

Type annotations for
[boto3.AutoScaling 1.15.7](https://boto3.amazonaws.com/v1/documentation/api/1.15.7/reference/services/autoscaling.html#AutoScaling) service
compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright)
and other tools.

Generated by [mypy-boto3-buider 3.1.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

- [mypy-boto3-autoscaling](#mypy-boto3-autoscaling)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Service Resource annotations](#service-resource-annotations)
    - [Other resources annotations](#other-resources-annotations)
    - [Collections annotations](#collections-annotations)
    - [Typed dictionations](#typed-dictionations)

## How to install

Install `boto3-stubs` for `AutoScaling` service.

```bash
python -m pip install boto3-stubs[autoscaling]
```

## Usage

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[autoscaling]` in your environment: `python -m pip install 'boto3-stubs[autoscaling]'`

Both type checking and auto-complete should work for `AutoScaling` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[autoscaling]` in your environment: `python -m pip install 'boto3-stubs[autoscaling]'`

Both type checking and auto-complete should work for `AutoScaling` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[autoscaling]` in your environment: `python -m pip install 'boto3-stubs[autoscaling]'`
- Run `mypy` as usual

Type checking should work for `AutoScaling` service.
No explicit type annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[autoscaling]` in your environment: `python -m pip install 'boto3-stubs[autoscaling]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `AutoScaling` service.
No explicit type annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`AutoScalingClient` provides annotations for `boto3.client("autoscaling")`.

```python
import boto3

from mypy_boto3_autoscaling import AutoScalingClient

client: AutoScalingClient = boto3.client("autoscaling")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: AutoScalingClient = session.client("autoscaling")
```

### Paginators annotations

`mypy_boto3_autoscaling.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_autoscaling import AutoScalingClient
from mypy_boto3_autoscaling.paginator import (
    DescribeAutoScalingGroupsPaginator,
    DescribeAutoScalingInstancesPaginator,
    DescribeLaunchConfigurationsPaginator,
    DescribeLoadBalancersPaginator,
    DescribeLoadBalancerTargetGroupsPaginator,
    DescribeNotificationConfigurationsPaginator,
    DescribePoliciesPaginator,
    DescribeScalingActivitiesPaginator,
    DescribeScheduledActionsPaginator,
    DescribeTagsPaginator,
)

client: AutoScalingClient = boto3.client("autoscaling")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
describe_auto_scaling_groups_paginator: DescribeAutoScalingGroupsPaginator = client.get_paginator("describe_auto_scaling_groups")
describe_auto_scaling_instances_paginator: DescribeAutoScalingInstancesPaginator = client.get_paginator("describe_auto_scaling_instances")
describe_launch_configurations_paginator: DescribeLaunchConfigurationsPaginator = client.get_paginator("describe_launch_configurations")
describe_load_balancer_target_groups_paginator: DescribeLoadBalancerTargetGroupsPaginator = client.get_paginator("describe_load_balancer_target_groups")
describe_load_balancers_paginator: DescribeLoadBalancersPaginator = client.get_paginator("describe_load_balancers")
describe_notification_configurations_paginator: DescribeNotificationConfigurationsPaginator = client.get_paginator("describe_notification_configurations")
describe_policies_paginator: DescribePoliciesPaginator = client.get_paginator("describe_policies")
describe_scaling_activities_paginator: DescribeScalingActivitiesPaginator = client.get_paginator("describe_scaling_activities")
describe_scheduled_actions_paginator: DescribeScheduledActionsPaginator = client.get_paginator("describe_scheduled_actions")
describe_tags_paginator: DescribeTagsPaginator = client.get_paginator("describe_tags")
```







### Typed dictionations

`mypy_boto3_autoscaling.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_autoscaling.type_defs import (
    ActivitiesTypeTypeDef,
    ActivityTypeDef,
    ActivityTypeTypeDef,
    AdjustmentTypeTypeDef,
    AlarmTypeDef,
    AutoScalingGroupsTypeTypeDef,
    AutoScalingGroupTypeDef,
    AutoScalingInstanceDetailsTypeDef,
    AutoScalingInstancesTypeTypeDef,
    BatchDeleteScheduledActionAnswerTypeDef,
    BatchPutScheduledUpdateGroupActionAnswerTypeDef,
    BlockDeviceMappingTypeDef,
    CancelInstanceRefreshAnswerTypeDef,
    CustomizedMetricSpecificationTypeDef,
    DescribeAccountLimitsAnswerTypeDef,
    DescribeAdjustmentTypesAnswerTypeDef,
    DescribeAutoScalingNotificationTypesAnswerTypeDef,
    DescribeInstanceRefreshesAnswerTypeDef,
    DescribeLifecycleHooksAnswerTypeDef,
    DescribeLifecycleHookTypesAnswerTypeDef,
    DescribeLoadBalancersResponseTypeDef,
    DescribeLoadBalancerTargetGroupsResponseTypeDef,
    DescribeMetricCollectionTypesAnswerTypeDef,
    DescribeNotificationConfigurationsAnswerTypeDef,
    DescribeTerminationPolicyTypesAnswerTypeDef,
    DetachInstancesAnswerTypeDef,
    EbsTypeDef,
    EnabledMetricTypeDef,
    EnterStandbyAnswerTypeDef,
    ExitStandbyAnswerTypeDef,
    FailedScheduledUpdateGroupActionRequestTypeDef,
    FilterTypeDef,
    InstanceMetadataOptionsTypeDef,
    InstanceMonitoringTypeDef,
    InstanceRefreshTypeDef,
    InstancesDistributionTypeDef,
    InstanceTypeDef,
    LaunchConfigurationsTypeTypeDef,
    LaunchConfigurationTypeDef,
    LaunchTemplateOverridesTypeDef,
    LaunchTemplateSpecificationTypeDef,
    LaunchTemplateTypeDef,
    LifecycleHookSpecificationTypeDef,
    LifecycleHookTypeDef,
    LoadBalancerStateTypeDef,
    LoadBalancerTargetGroupStateTypeDef,
    MetricCollectionTypeTypeDef,
    MetricDimensionTypeDef,
    MetricGranularityTypeTypeDef,
    MixedInstancesPolicyTypeDef,
    NotificationConfigurationTypeDef,
    PaginatorConfigTypeDef,
    PoliciesTypeTypeDef,
    PolicyARNTypeTypeDef,
    PredefinedMetricSpecificationTypeDef,
    ProcessesTypeTypeDef,
    ProcessTypeTypeDef,
    RefreshPreferencesTypeDef,
    ScalingPolicyTypeDef,
    ScheduledActionsTypeTypeDef,
    ScheduledUpdateGroupActionRequestTypeDef,
    ScheduledUpdateGroupActionTypeDef,
    StartInstanceRefreshAnswerTypeDef,
    StepAdjustmentTypeDef,
    SuspendedProcessTypeDef,
    TagDescriptionTypeDef,
    TagsTypeTypeDef,
    TagTypeDef,
    TargetTrackingConfigurationTypeDef,
)

def get_structure() -> ActivityTypeDef:
    return {
      ...
    }
```
